#ifndef WNEW_H
#define WNEW_H

#include <QWidget>
#include <QtGui>

namespace Ui {
    class WNew;
}

class WNew : public QWidget
{
    Q_OBJECT

public:
    explicit WNew(QWidget *parent = 0);
    ~WNew();

public slots:
    void reorderUI();

private slots:
    void on_btnEyesRight_pressed();
    void on_btnEyesRight_clicked();
    void on_btnEyesRight_released();

    void on_btnEyesLeft_pressed();
    void on_btnEyesLeft_clicked();
    void on_btnEyesLeft_released();

    void on_btnHeadLeft_pressed();
    void on_btnHeadLeft_clicked();
    void on_btnHeadLeft_released();

    void on_btnHeadRight_pressed();
    void on_btnHeadRight_clicked();
    void on_btnHeadRight_released();

    void on_btnMouthLeft_pressed();
    void on_btnMouthLeft_clicked();
    void on_btnMouthLeft_released();

    void on_btnMouthRight_pressed();
    void on_btnMouthRight_clicked();
    void on_btnMouthRight_released();

    void on_btnSave_clicked();

private:
    Ui::WNew *ui;

    QLabel *imgEyes;
    QLabel *imgMouth;

    QStringList heads;
    QStringList mouths;
    QStringList eyes;
    int headIndex;
    int mouthIndex;
    int eyesIndex;
};

#endif // WNEW_H
